%global upstream_name marshmallow

Name:           python-%{upstream_name}
Version:        3.20.1
Release:        %mkrel 3
Summary:        Python library for converting complex datatypes to and from primitive types
Group:          Development/Python
License:        MIT
URL:            https://marshmallow.readthedocs.org/
# Using Github instead of PyPI because the PyPI tarballs don't include tests,
# docs, or examples, and upstream does not want to change that.
# https://github.com/marshmallow-code/marshmallow/issues/201
Source0:        https://github.com/marshmallow-code/marshmallow/archive/%{version}/%{upstream_name}-%{version}.tar.gz
# remove dependency on bundled ordered_set
Patch0:         ordered_set.patch

BuildArch:      noarch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-ordered-set

%description
Marshmallow is a framework-agnostic library for converting complex datatypes,
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%package -n python3-%{upstream_name}
Summary:        Python 3 library for converting complex datatypes to and from primitive types
Group:          Development/Python
Requires:       python3-dateutil
Requires:       python3-ordered-set

%description -n python3-%{upstream_name}
Marshmallow is a framework-agnostic library for converting complex datatypes,
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%prep
%autosetup -n %{upstream_name}-%{version} -p1

# remove bundled library
# instead of orderedsett we patch code to usu python-ordered-set
# ordereddict.py is used only for compatibility with python2.6,
# which we do not need
rm -f ./marshmallow/ordereddict.py ./marshmallow/orderedset.py

%generate_buildrequires
%pyproject_buildrequires -t -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files marshmallow

%check
%tox

%files -n python3-%{upstream_name} -f %{pyproject_files}
%license LICENSE
%doc CHANGELOG.rst AUTHORS.rst README.rst


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 3.20.1-3.mga10
+ Revision: 2240226
- Mageia 10 Mass Rebuild

* Sun Mar 02 2025 wally <wally> 3.20.1-2.mga10
+ Revision: 2157248
- rebuild for python3.13

* Sat Dec 09 2023 wally <wally> 3.20.1-1.mga10
+ Revision: 2016378
- new version 3.20.1

* Wed Sep 07 2022 wally <wally> 3.17.0-2.mga9
+ Revision: 1884985
- drop broken docs subpkg

* Wed Sep 07 2022 neoclust <neoclust> 3.17.0-1.mga9
+ Revision: 1884917
- New version  3.17.0

* Tue Mar 29 2022 umeabot <umeabot> 3.14.1-2.mga9
+ Revision: 1832614
- Mageia 9 Mass Rebuild

* Tue Feb 15 2022 wally <wally> 3.14.1-1.mga9
+ Revision: 1775241
- new version 3.14.1
- rebuild for python3.10

* Sun Aug 29 2021 wally <wally> 3.13.0-1.mga9
+ Revision: 1743431
- new version 3.13.0

* Mon Mar 15 2021 wally <wally> 3.10.0-1.mga9
+ Revision: 1703316
- new version 3.10.0
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 3.0.5-2.mga8
+ Revision: 1531802
- Mageia 8 Mass Rebuild

* Sun Sep 15 2019 wally <wally> 3.0.5-1.mga8
+ Revision: 1440950
- new verion 3.0.5

* Sun Sep 08 2019 wally <wally> 3.0.3-1.mga8
+ Revision: 1438328
- new version 3.0.3
- rebuild for python3.8

* Tue Aug 20 2019 wally <wally> 3.0.0-1.mga8
+ Revision: 1430528
- new version 3.0.0
- drop python2 support

* Sun Feb 03 2019 luigiwalser <luigiwalser> 2.2.1-0.8.gitea1def9.mga7
+ Revision: 1362756
- rediff patch from fedora to fix CVE-2018-17175

* Mon Jan 07 2019 wally <wally> 2.2.1-0.7.gitea1def9.mga7
+ Revision: 1350663
- rebuild for python3.7

* Thu Sep 20 2018 umeabot <umeabot> 2.2.1-0.6.gitea1def9.mga7
+ Revision: 1289183
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 2.2.1-0.5.gitea1def9.mga7
+ Revision: 1135492
- Rebuild for python 3.6

* Sun May 15 2016 ngompa <ngompa> 2.2.1-0.4.gitea1def9.mga6
+ Revision: 1015705
- imported package python-marshmallow


* Sat May 14 2016 Neal Gompa <ngompa13@gmail.com> - 2.2.1-0.4.gitea1def9
- Port to Mageia

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.1-0.3.gitea1def9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 18 2015 Miroslav Suchý <msuchy@redhat.com> 2.2.1-0.2.gitea1def9
- add BR simplejson
- add BR python-tox

* Wed Nov 18 2015 Miroslav Suchý <msuchy@redhat.com> 2.2.1-0.1.gitea1def9
- rebase to 2.2.1

* Wed Nov 18 2015 Miroslav Suchý <miroslav@suchy.cz> 2.2.1-0.0.gitea1def9
- rebase to 2.2.1

* Fri Sep 11 2015 Miroslav Suchý <miroslav@suchy.cz> 2.0.0-0.6.gita8b3385
- 1219288 - fix ownership of docdir and use correct release number

* Fri Sep 11 2015 Miroslav Suchý <msuchy@redhat.com> 2.0.0-0.5.a8b3385
- add short git hash to release number

* Fri Sep 11 2015 Miroslav Suchý <msuchy@redhat.com> 2.0.0b5-4
- create -doc subpackages
- 1219288 - reorganize spec file

* Mon Sep 07 2015 Miroslav Suchý <msuchy@redhat.com> 2.0.0b5-3
- explicitely list docdir

* Mon Sep 07 2015 Miroslav Suchý <msuchy@redhat.com> 2.0.0b5-2
- unbundle ordereddict and ordered set
- add documentation

* Mon Aug 24 2015 Valentin Gologuzov <vgologuz@redhat.com> - 2.0.0b5-1
- Rebuild with the newest upstream version

* Thu May 07 2015 Dan Callaghan <dcallagh@redhat.com> - 1.2.6-1
- initial version
